@@ -269,18 +269,6 @@ class TestValidationErrorMessages(TestCase):
         message = self.message_for(instance=1, schema={"type": list(types)})
         self.assertEqual(message, "1 is not of type 'string', 'object'")
 
-    def test_object_without_title_type_failure(self):
-        type = {"type": [{"minimum": 3}]}
-        message = self.message_for(
-            instance=1,
-            schema={"type": [type]},
-            cls=validators.Draft3Validator,
-        )
-        self.assertEqual(
-            message,
-            "1 is not of type {'type': [{'minimum': 3}]}",
-        )
-
     def test_object_with_named_type_failure(self):
         schema = {"type": [{"name": "Foo", "minimum": 3}]}
         message = self.message_for(
@@ -308,6 +296,18 @@ class TestValidationErrorMessages(TestCase):
         )
         self.assertEqual(message, "'foo' is a dependency of 'bar'")
 
+    def test_object_without_title_type_failure_draft3(self):
+        type = {"type": [{"minimum": 3}]}
+        message = self.message_for(
+            instance=1,
+            schema={"type": [type]},
+            cls=validators.Draft3Validator,
+        )
+        self.assertEqual(
+            message,
+            "1 is not of type {'type': [{'minimum': 3}]}",
+        )
+
     def test_dependencies_list_draft3(self):
         depend, on = "bar", "foo"
         schema = {"dependencies": {depend: [on]}}
@@ -624,7 +624,7 @@ class TestValidationErrorMessages(TestCase):
 
 
 class TestValidationErrorDetails(TestCase):
-    # TODO: These really need unit tests for each individual validator, rather
+    # TODO: These really need unit tests for each individual keyword, rather
     #       than just these higher level tests.
     def test_anyOf(self):
         instance = 5
@@ -1463,6 +1463,38 @@ class ValidatorTestMixin(MetaSchemaTestsMixin, object):
         with self.assertRaises(exceptions.ValidationError):
             validator.validate(None)
 
+    def test_evolve(self):
+        ref, schema = "someCoolRef", {"type": "integer"}
+        resolver = validators.RefResolver("", {}, store={ref: schema})
+
+        validator = self.Validator(schema, resolver=resolver)
+        new = validator.evolve(schema={"type": "string"})
+
+        expected = self.Validator({"type": "string"}, resolver=resolver)
+
+        self.assertEqual(new, expected)
+        self.assertNotEqual(new, validator)
+
+    def test_evolve_with_subclass(self):
+        """
+        Subclassing validators isn't supported public API, but some users have
+        done it, because we don't actually error entirely when it's done :/
+
+        We need to deprecate doing so first to help as many of these users
+        ensure they can move to supported APIs, but this test ensures that in
+        the interim, we haven't broken those users.
+        """
+
+        @attr.s
+        class OhNo(self.Validator):
+            foo = attr.ib(factory=lambda: [1, 2, 3])
+
+        validator = OhNo({})
+        self.assertEqual(validator.foo, [1, 2, 3])
+
+        new = validator.evolve(schema={"type": "integer"})
+        self.assertEqual(new.foo, [1, 2, 3])
+
     def test_it_delegates_to_a_legacy_ref_resolver(self):
         """
         Legacy RefResolvers support only the context manager form of
